@@ -1,11 +1,21 @@
-#' Compute Stressed Factors
+#' @title Compute Stressed Factors
+#'
+#' @description Computes stressed factors.
+#'
+#' @param dep_variable A numeric vector representing the dependent variable (e.g., GDP growth, inflation).
+#' @param factors A matrix or data frame of factor estimates, typically extracted from an MLDFM model.
+#' @param ellipsoids A list of matrices, where each matrix represents a stressed ellipsoid for a given time period. 
+#' @param h Integer representing the forecast horizon (in time steps). It defines the lag used in regression.
+#' @param qtau Numeric. The quantile level used in quantile regression (default is 0.05).
+#' @param min Logical. If \code{TRUE}, the function uses a stepwise minimization method. If \code{FALSE}, it uses a stepwise maximization method.
+#'
+#' @return A matrix of stressed factors, with each row representing a time period and each column representing a factor.
 #'
 #' @import quantreg
 #' @importFrom stats as.formula
 #' 
 #' @keywords internal
-#' 
-compute_stressed_factors <- function(dep_variable, factors, scenario, h, QTAU, min) {
+compute_stressed_factors <- function(dep_variable, factors, ellipsoids, h, qtau, min) {
   
   
   t <- nrow(factors)
@@ -34,7 +44,7 @@ compute_stressed_factors <- function(dep_variable, factors, scenario, h, QTAU, m
   formula <- as.formula(paste("Y ~ LagY", factor_names_concat, sep = " + "))
 
   # qreg
-  fit_q <- rq(formula, tau = QTAU, data = reg_data)
+  fit_q <- rq(formula, tau = qtau, data = reg_data)
   summary_fit <- summary(fit_q, se = "ker",covariance=TRUE)
   coefficients <- summary_fit$coefficients[, 1]
  
@@ -44,7 +54,7 @@ compute_stressed_factors <- function(dep_variable, factors, scenario, h, QTAU, m
   
   # Loop over time to compute stressed factors
   for (tt in 1:t){
-    ellips <- scenario[[tt]]
+    ellips <- ellipsoids[[tt]]
     pred <- coefficients[1] + coefficients[2] * Y[tt] + ellips %*% coefficients[3:(2 + r)]
     index <- if (min) which.min(pred) else which.max(pred)
     stressed_factors[tt, ] <- ellips[index, ]
